pub struct AsyncDriver<T, P: Parse> { /* private fields */ }
Asynchronous driver for parsers

This is a generic asynchronous driver for objects implementing the Parse trait.

In general, it is advised to use the AsyncParser alias which specializes this struct for use with the default Parser.

Implementations

Create a new parser with default options, wrapping the given reader.

Create a new parser while configuring the lexer with the given options.

Create a fully customized parser from a lexer and a parser component.

Decompose the AsyncDriver into its parts

Access the inner AsyncBufRead

Access the inner AsyncBufRead, mutably

Access the lexer

Access the lexer, mutably

Access the parser

Access the parser, mutably

Release temporary buffers and other ephemeral allocations.

This is sensible to call when it is expected that no more data will be processed by the parser for a while and the memory is better used elsewhere.